'''_428.py

CylindricalGearSingleFlankRating
'''


from mastapy.materials import _243
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.gears.rating.cylindrical import _423
from mastapy.gears.rating import _329
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SINGLE_FLANK_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical', 'CylindricalGearSingleFlankRating')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearSingleFlankRating',)


class CylindricalGearSingleFlankRating(_329.GearSingleFlankRating):
    '''CylindricalGearSingleFlankRating

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_SINGLE_FLANK_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearSingleFlankRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def metal_plastic(self) -> '_243.MetalPlasticType':
        '''MetalPlasticType: 'MetalPlastic' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.MetalPlastic)
        return constructor.new(_243.MetalPlasticType)(value) if value else None

    @property
    def normal_pressure_angle(self) -> 'float':
        '''float: 'NormalPressureAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalPressureAngle

    @property
    def helix_angle(self) -> 'float':
        '''float: 'HelixAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HelixAngle

    @property
    def pitch_diameter(self) -> 'float':
        '''float: 'PitchDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PitchDiameter

    @property
    def combined_tip_relief(self) -> 'float':
        '''float: 'CombinedTipRelief' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CombinedTipRelief

    @property
    def base_diameter(self) -> 'float':
        '''float: 'BaseDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BaseDiameter

    @property
    def rim_thickness(self) -> 'float':
        '''float: 'RimThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RimThickness

    @property
    def tooth_root_chord_at_critical_section(self) -> 'float':
        '''float: 'ToothRootChordAtCriticalSection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootChordAtCriticalSection

    @property
    def bending_moment_arm(self) -> 'float':
        '''float: 'BendingMomentArm' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BendingMomentArm

    @property
    def root_fillet_radius(self) -> 'float':
        '''float: 'RootFilletRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RootFilletRadius

    @property
    def flank_roughness_rz(self) -> 'float':
        '''float: 'FlankRoughnessRz' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FlankRoughnessRz

    @property
    def fillet_roughness_rz(self) -> 'float':
        '''float: 'FilletRoughnessRz' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FilletRoughnessRz

    @property
    def tooth_passing_speed(self) -> 'float':
        '''float: 'ToothPassingSpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothPassingSpeed

    @property
    def gear_rotation_speed(self) -> 'float':
        '''float: 'GearRotationSpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GearRotationSpeed

    @property
    def normal_module(self) -> 'float':
        '''float: 'NormalModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalModule

    @property
    def transverse_pressure_angle(self) -> 'float':
        '''float: 'TransversePressureAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransversePressureAngle

    @property
    def base_helix_angle(self) -> 'float':
        '''float: 'BaseHelixAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BaseHelixAngle

    @property
    def base_transverse_pitch(self) -> 'float':
        '''float: 'BaseTransversePitch' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BaseTransversePitch

    @property
    def normal_base_pitch(self) -> 'float':
        '''float: 'NormalBasePitch' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalBasePitch

    @property
    def angular_velocity(self) -> 'float':
        '''float: 'AngularVelocity' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AngularVelocity

    @property
    def contact_safety_factor_for_fatigue(self) -> 'float':
        '''float: 'ContactSafetyFactorForFatigue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactSafetyFactorForFatigue

    @property
    def bending_safety_factor_for_fatigue(self) -> 'float':
        '''float: 'BendingSafetyFactorForFatigue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BendingSafetyFactorForFatigue

    @property
    def safety_factor_wear(self) -> 'float':
        '''float: 'SafetyFactorWear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorWear

    @property
    def reliability_contact(self) -> 'float':
        '''float: 'ReliabilityContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ReliabilityContact

    @property
    def reliability_bending(self) -> 'float':
        '''float: 'ReliabilityBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ReliabilityBending

    @property
    def damage_contact(self) -> 'float':
        '''float: 'DamageContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DamageContact

    @property
    def static_safety_factor_contact(self) -> 'float':
        '''float: 'StaticSafetyFactorContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StaticSafetyFactorContact

    @property
    def damage_bending(self) -> 'float':
        '''float: 'DamageBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DamageBending

    @property
    def static_safety_factor_bending(self) -> 'float':
        '''float: 'StaticSafetyFactorBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StaticSafetyFactorBending

    @property
    def damage_wear(self) -> 'float':
        '''float: 'DamageWear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DamageWear

    @property
    def thermal_contact_coefficient_for_report(self) -> 'float':
        '''float: 'ThermalContactCoefficientForReport' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ThermalContactCoefficientForReport

    @property
    def contact_stress_source(self) -> 'str':
        '''str: 'ContactStressSource' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactStressSource

    @property
    def tooth_root_stress_source(self) -> 'str':
        '''str: 'ToothRootStressSource' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootStressSource

    @property
    def pitting_stress_limit(self) -> 'float':
        '''float: 'PittingStressLimit' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PittingStressLimit

    @property
    def pitting_stress_limit_for_reference_stress(self) -> 'float':
        '''float: 'PittingStressLimitForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PittingStressLimitForReferenceStress

    @property
    def pitting_stress_limit_for_static_stress(self) -> 'float':
        '''float: 'PittingStressLimitForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PittingStressLimitForStaticStress

    @property
    def tooth_root_stress_limit_for_static_stress(self) -> 'float':
        '''float: 'ToothRootStressLimitForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootStressLimitForStaticStress

    @property
    def tooth_root_stress_limit_for_reference_stress(self) -> 'float':
        '''float: 'ToothRootStressLimitForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootStressLimitForReferenceStress

    @property
    def tooth_root_stress_limit(self) -> 'float':
        '''float: 'ToothRootStressLimit' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootStressLimit

    @property
    def tooth_root_stress(self) -> 'float':
        '''float: 'ToothRootStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootStress

    @property
    def calculated_contact_stress(self) -> 'float':
        '''float: 'CalculatedContactStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CalculatedContactStress

    @property
    def permissible_contact_stress(self) -> 'float':
        '''float: 'PermissibleContactStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleContactStress

    @property
    def permissible_contact_stress_for_static_stress(self) -> 'float':
        '''float: 'PermissibleContactStressForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleContactStressForStaticStress

    @property
    def permissible_contact_stress_for_reference_stress(self) -> 'float':
        '''float: 'PermissibleContactStressForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleContactStressForReferenceStress

    @property
    def permissible_tooth_root_bending_stress(self) -> 'float':
        '''float: 'PermissibleToothRootBendingStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleToothRootBendingStress

    @property
    def permissible_tooth_root_bending_stress_for_static_stress(self) -> 'float':
        '''float: 'PermissibleToothRootBendingStressForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleToothRootBendingStressForStaticStress

    @property
    def permissible_tooth_root_bending_stress_for_reference_stress(self) -> 'float':
        '''float: 'PermissibleToothRootBendingStressForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleToothRootBendingStressForReferenceStress

    @property
    def permissible_linear_wear(self) -> 'float':
        '''float: 'PermissibleLinearWear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleLinearWear

    @property
    def averaged_linear_wear(self) -> 'float':
        '''float: 'AveragedLinearWear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AveragedLinearWear

    @property
    def minimum_factor_of_safety_pitting_fatigue(self) -> 'float':
        '''float: 'MinimumFactorOfSafetyPittingFatigue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumFactorOfSafetyPittingFatigue

    @property
    def minimum_factor_of_safety_bending_fatigue(self) -> 'float':
        '''float: 'MinimumFactorOfSafetyBendingFatigue' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumFactorOfSafetyBendingFatigue

    @property
    def allowable_stress_number_contact(self) -> 'float':
        '''float: 'AllowableStressNumberContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AllowableStressNumberContact

    @property
    def allowable_stress_number_bending(self) -> 'float':
        '''float: 'AllowableStressNumberBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AllowableStressNumberBending

    @property
    def nominal_stress_number_bending(self) -> 'float':
        '''float: 'NominalStressNumberBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NominalStressNumberBending

    @property
    def reversed_bending_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'ReversedBendingFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(overridable.Overridable_float)(self.wrapped.ReversedBendingFactor) if self.wrapped.ReversedBendingFactor else None

    @property
    def life_factor_for_contact_stress(self) -> 'float':
        '''float: 'LifeFactorForContactStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LifeFactorForContactStress

    @property
    def stress_cycle_factor_bending(self) -> 'float':
        '''float: 'StressCycleFactorBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressCycleFactorBending

    @property
    def size_factor_contact(self) -> 'float':
        '''float: 'SizeFactorContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SizeFactorContact

    @property
    def rim_thickness_factor(self) -> 'float':
        '''float: 'RimThicknessFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RimThicknessFactor

    @property
    def welding_structural_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'WeldingStructuralFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(overridable.Overridable_float)(self.wrapped.WeldingStructuralFactor) if self.wrapped.WeldingStructuralFactor else None

    @property
    def rim_thickness_over_normal_module(self) -> 'float':
        '''float: 'RimThicknessOverNormalModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RimThicknessOverNormalModule

    @property
    def transverse_pitch(self) -> 'float':
        '''float: 'TransversePitch' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransversePitch

    @property
    def axial_pitch(self) -> 'float':
        '''float: 'AxialPitch' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AxialPitch

    @property
    def transverse_module(self) -> 'float':
        '''float: 'TransverseModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseModule

    @property
    def normal_pitch(self) -> 'float':
        '''float: 'NormalPitch' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalPitch

    @property
    def geometry_data_source_for_rating(self) -> '_423.CylindricalGearRatingGeometryDataSource':
        '''CylindricalGearRatingGeometryDataSource: 'GeometryDataSourceForRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.GeometryDataSourceForRating)
        return constructor.new(_423.CylindricalGearRatingGeometryDataSource)(value) if value else None



'''_1750.py

LoadedRollerStripLoadResults
'''


from mastapy import _0
from mastapy._internal.python_net import python_net_import

_LOADED_ROLLER_STRIP_LOAD_RESULTS = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedRollerStripLoadResults')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedRollerStripLoadResults',)


class LoadedRollerStripLoadResults(_0.APIBase):
    '''LoadedRollerStripLoadResults

    This is a mastapy class.
    '''

    TYPE = _LOADED_ROLLER_STRIP_LOAD_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedRollerStripLoadResults.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_3900.py

ConnectionCompoundPowerFlow
'''


from typing import List

from mastapy.system_model.analyses_and_results.power_flows import _3767
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.analysis_cases import _7223
from mastapy._internal.python_net import python_net_import

_CONNECTION_COMPOUND_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows.Compound', 'ConnectionCompoundPowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('ConnectionCompoundPowerFlow',)


class ConnectionCompoundPowerFlow(_7223.ConnectionCompoundAnalysis):
    '''ConnectionCompoundPowerFlow

    This is a mastapy class.
    '''

    TYPE = _CONNECTION_COMPOUND_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConnectionCompoundPowerFlow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_analysis_cases(self) -> 'List[_3767.ConnectionPowerFlow]':
        '''List[ConnectionPowerFlow]: 'ConnectionAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCases, constructor.new(_3767.ConnectionPowerFlow))
        return value

    @property
    def connection_analysis_cases_ready(self) -> 'List[_3767.ConnectionPowerFlow]':
        '''List[ConnectionPowerFlow]: 'ConnectionAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCasesReady, constructor.new(_3767.ConnectionPowerFlow))
        return value



'''_6369.py

BevelDifferentialGearSetCompoundCriticalSpeedAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2223
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.critical_speed_analyses.compound import _6367, _6368, _6374
from mastapy.system_model.analyses_and_results.critical_speed_analyses import _6238
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_SET_COMPOUND_CRITICAL_SPEED_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses.Compound', 'BevelDifferentialGearSetCompoundCriticalSpeedAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearSetCompoundCriticalSpeedAnalysis',)


class BevelDifferentialGearSetCompoundCriticalSpeedAnalysis(_6374.BevelGearSetCompoundCriticalSpeedAnalysis):
    '''BevelDifferentialGearSetCompoundCriticalSpeedAnalysis

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_SET_COMPOUND_CRITICAL_SPEED_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearSetCompoundCriticalSpeedAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2223.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2223.BevelDifferentialGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2223.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2223.BevelDifferentialGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def bevel_differential_gears_compound_critical_speed_analysis(self) -> 'List[_6367.BevelDifferentialGearCompoundCriticalSpeedAnalysis]':
        '''List[BevelDifferentialGearCompoundCriticalSpeedAnalysis]: 'BevelDifferentialGearsCompoundCriticalSpeedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialGearsCompoundCriticalSpeedAnalysis, constructor.new(_6367.BevelDifferentialGearCompoundCriticalSpeedAnalysis))
        return value

    @property
    def bevel_differential_meshes_compound_critical_speed_analysis(self) -> 'List[_6368.BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis]':
        '''List[BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis]: 'BevelDifferentialMeshesCompoundCriticalSpeedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialMeshesCompoundCriticalSpeedAnalysis, constructor.new(_6368.BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_6238.BevelDifferentialGearSetCriticalSpeedAnalysis]':
        '''List[BevelDifferentialGearSetCriticalSpeedAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_6238.BevelDifferentialGearSetCriticalSpeedAnalysis))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_6238.BevelDifferentialGearSetCriticalSpeedAnalysis]':
        '''List[BevelDifferentialGearSetCriticalSpeedAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_6238.BevelDifferentialGearSetCriticalSpeedAnalysis))
        return value



'''_6621.py

PlanetManufactureError
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_PLANET_MANUFACTURE_ERROR = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'PlanetManufactureError')


__docformat__ = 'restructuredtext en'
__all__ = ('PlanetManufactureError',)


class PlanetManufactureError(_0.APIBase):
    '''PlanetManufactureError

    This is a mastapy class.
    '''

    TYPE = _PLANET_MANUFACTURE_ERROR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlanetManufactureError.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def radial_error(self) -> 'float':
        '''float: 'RadialError' is the original name of this property.'''

        return self.wrapped.RadialError

    @radial_error.setter
    def radial_error(self, value: 'float'):
        self.wrapped.RadialError = float(value) if value else 0.0

    @property
    def tangential_error(self) -> 'float':
        '''float: 'TangentialError' is the original name of this property.'''

        return self.wrapped.TangentialError

    @tangential_error.setter
    def tangential_error(self, value: 'float'):
        self.wrapped.TangentialError = float(value) if value else 0.0

    @property
    def radial_tilt_error(self) -> 'float':
        '''float: 'RadialTiltError' is the original name of this property.'''

        return self.wrapped.RadialTiltError

    @radial_tilt_error.setter
    def radial_tilt_error(self, value: 'float'):
        self.wrapped.RadialTiltError = float(value) if value else 0.0

    @property
    def tangential_tilt_error(self) -> 'float':
        '''float: 'TangentialTiltError' is the original name of this property.'''

        return self.wrapped.TangentialTiltError

    @tangential_tilt_error.setter
    def tangential_tilt_error(self, value: 'float'):
        self.wrapped.TangentialTiltError = float(value) if value else 0.0

    @property
    def x_tilt_error(self) -> 'float':
        '''float: 'XTiltError' is the original name of this property.'''

        return self.wrapped.XTiltError

    @x_tilt_error.setter
    def x_tilt_error(self, value: 'float'):
        self.wrapped.XTiltError = float(value) if value else 0.0

    @property
    def y_tilt_error(self) -> 'float':
        '''float: 'YTiltError' is the original name of this property.'''

        return self.wrapped.YTiltError

    @y_tilt_error.setter
    def y_tilt_error(self, value: 'float'):
        self.wrapped.YTiltError = float(value) if value else 0.0

    @property
    def x_error(self) -> 'float':
        '''float: 'XError' is the original name of this property.'''

        return self.wrapped.XError

    @x_error.setter
    def x_error(self, value: 'float'):
        self.wrapped.XError = float(value) if value else 0.0

    @property
    def y_error(self) -> 'float':
        '''float: 'YError' is the original name of this property.'''

        return self.wrapped.YError

    @y_error.setter
    def y_error(self, value: 'float'):
        self.wrapped.YError = float(value) if value else 0.0

    @property
    def angular_error(self) -> 'float':
        '''float: 'AngularError' is the original name of this property.'''

        return self.wrapped.AngularError

    @angular_error.setter
    def angular_error(self, value: 'float'):
        self.wrapped.AngularError = float(value) if value else 0.0

    @property
    def radial_error_carrier(self) -> 'float':
        '''float: 'RadialErrorCarrier' is the original name of this property.'''

        return self.wrapped.RadialErrorCarrier

    @radial_error_carrier.setter
    def radial_error_carrier(self, value: 'float'):
        self.wrapped.RadialErrorCarrier = float(value) if value else 0.0

    @property
    def angle_of_error_in_pin_coordinate_system(self) -> 'float':
        '''float: 'AngleOfErrorInPinCoordinateSystem' is the original name of this property.'''

        return self.wrapped.AngleOfErrorInPinCoordinateSystem

    @angle_of_error_in_pin_coordinate_system.setter
    def angle_of_error_in_pin_coordinate_system(self, value: 'float'):
        self.wrapped.AngleOfErrorInPinCoordinateSystem = float(value) if value else 0.0

    @property
    def hole_radial_displacement(self) -> 'float':
        '''float: 'HoleRadialDisplacement' is the original name of this property.'''

        return self.wrapped.HoleRadialDisplacement

    @hole_radial_displacement.setter
    def hole_radial_displacement(self, value: 'float'):
        self.wrapped.HoleRadialDisplacement = float(value) if value else 0.0



'''_4148.py

AssemblyCompoundParametricStudyTool
'''


from typing import List

from mastapy.system_model.analyses_and_results.parametric_study_tools import _4048, _4001
from mastapy._internal import constructor, conversion
from mastapy.system_model.part_model import _2143, _2182
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.parametric_study_tools.compound import (
    _4149, _4151, _4154, _4160,
    _4161, _4162, _4167, _4172,
    _4182, _4184, _4186, _4190,
    _4196, _4197, _4198, _4205,
    _4212, _4215, _4216, _4217,
    _4219, _4221, _4226, _4227,
    _4228, _4237, _4230, _4232,
    _4236, _4242, _4243, _4248,
    _4251, _4254, _4258, _4262,
    _4266, _4269, _4141
)
from mastapy._internal.python_net import python_net_import

_ASSEMBLY_COMPOUND_PARAMETRIC_STUDY_TOOL = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools.Compound', 'AssemblyCompoundParametricStudyTool')


__docformat__ = 'restructuredtext en'
__all__ = ('AssemblyCompoundParametricStudyTool',)


class AssemblyCompoundParametricStudyTool(_4141.AbstractAssemblyCompoundParametricStudyTool):
    '''AssemblyCompoundParametricStudyTool

    This is a mastapy class.
    '''

    TYPE = _ASSEMBLY_COMPOUND_PARAMETRIC_STUDY_TOOL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'AssemblyCompoundParametricStudyTool.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def all_duty_cycle_results(self) -> '_4048.DutyCycleResultsForAllComponents':
        '''DutyCycleResultsForAllComponents: 'AllDutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_4048.DutyCycleResultsForAllComponents)(self.wrapped.AllDutyCycleResults) if self.wrapped.AllDutyCycleResults else None

    @property
    def component_design(self) -> '_2143.Assembly':
        '''Assembly: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2143.Assembly.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to Assembly. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2143.Assembly':
        '''Assembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2143.Assembly.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to Assembly. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_4001.AssemblyParametricStudyTool]':
        '''List[AssemblyParametricStudyTool]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_4001.AssemblyParametricStudyTool))
        return value

    @property
    def bearings(self) -> 'List[_4149.BearingCompoundParametricStudyTool]':
        '''List[BearingCompoundParametricStudyTool]: 'Bearings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Bearings, constructor.new(_4149.BearingCompoundParametricStudyTool))
        return value

    @property
    def belt_drives(self) -> 'List[_4151.BeltDriveCompoundParametricStudyTool]':
        '''List[BeltDriveCompoundParametricStudyTool]: 'BeltDrives' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BeltDrives, constructor.new(_4151.BeltDriveCompoundParametricStudyTool))
        return value

    @property
    def bevel_differential_gear_sets(self) -> 'List[_4154.BevelDifferentialGearSetCompoundParametricStudyTool]':
        '''List[BevelDifferentialGearSetCompoundParametricStudyTool]: 'BevelDifferentialGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialGearSets, constructor.new(_4154.BevelDifferentialGearSetCompoundParametricStudyTool))
        return value

    @property
    def bolts(self) -> 'List[_4160.BoltCompoundParametricStudyTool]':
        '''List[BoltCompoundParametricStudyTool]: 'Bolts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Bolts, constructor.new(_4160.BoltCompoundParametricStudyTool))
        return value

    @property
    def bolted_joints(self) -> 'List[_4161.BoltedJointCompoundParametricStudyTool]':
        '''List[BoltedJointCompoundParametricStudyTool]: 'BoltedJoints' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BoltedJoints, constructor.new(_4161.BoltedJointCompoundParametricStudyTool))
        return value

    @property
    def clutches(self) -> 'List[_4162.ClutchCompoundParametricStudyTool]':
        '''List[ClutchCompoundParametricStudyTool]: 'Clutches' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Clutches, constructor.new(_4162.ClutchCompoundParametricStudyTool))
        return value

    @property
    def concept_couplings(self) -> 'List[_4167.ConceptCouplingCompoundParametricStudyTool]':
        '''List[ConceptCouplingCompoundParametricStudyTool]: 'ConceptCouplings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptCouplings, constructor.new(_4167.ConceptCouplingCompoundParametricStudyTool))
        return value

    @property
    def concept_gear_sets(self) -> 'List[_4172.ConceptGearSetCompoundParametricStudyTool]':
        '''List[ConceptGearSetCompoundParametricStudyTool]: 'ConceptGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptGearSets, constructor.new(_4172.ConceptGearSetCompoundParametricStudyTool))
        return value

    @property
    def cv_ts(self) -> 'List[_4182.CVTCompoundParametricStudyTool]':
        '''List[CVTCompoundParametricStudyTool]: 'CVTs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CVTs, constructor.new(_4182.CVTCompoundParametricStudyTool))
        return value

    @property
    def cycloidal_assemblies(self) -> 'List[_4184.CycloidalAssemblyCompoundParametricStudyTool]':
        '''List[CycloidalAssemblyCompoundParametricStudyTool]: 'CycloidalAssemblies' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CycloidalAssemblies, constructor.new(_4184.CycloidalAssemblyCompoundParametricStudyTool))
        return value

    @property
    def cycloidal_discs(self) -> 'List[_4186.CycloidalDiscCompoundParametricStudyTool]':
        '''List[CycloidalDiscCompoundParametricStudyTool]: 'CycloidalDiscs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CycloidalDiscs, constructor.new(_4186.CycloidalDiscCompoundParametricStudyTool))
        return value

    @property
    def cylindrical_gear_sets(self) -> 'List[_4190.CylindricalGearSetCompoundParametricStudyTool]':
        '''List[CylindricalGearSetCompoundParametricStudyTool]: 'CylindricalGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalGearSets, constructor.new(_4190.CylindricalGearSetCompoundParametricStudyTool))
        return value

    @property
    def face_gear_sets(self) -> 'List[_4196.FaceGearSetCompoundParametricStudyTool]':
        '''List[FaceGearSetCompoundParametricStudyTool]: 'FaceGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.FaceGearSets, constructor.new(_4196.FaceGearSetCompoundParametricStudyTool))
        return value

    @property
    def fe_parts(self) -> 'List[_4197.FEPartCompoundParametricStudyTool]':
        '''List[FEPartCompoundParametricStudyTool]: 'FEParts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.FEParts, constructor.new(_4197.FEPartCompoundParametricStudyTool))
        return value

    @property
    def flexible_pin_assemblies(self) -> 'List[_4198.FlexiblePinAssemblyCompoundParametricStudyTool]':
        '''List[FlexiblePinAssemblyCompoundParametricStudyTool]: 'FlexiblePinAssemblies' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.FlexiblePinAssemblies, constructor.new(_4198.FlexiblePinAssemblyCompoundParametricStudyTool))
        return value

    @property
    def hypoid_gear_sets(self) -> 'List[_4205.HypoidGearSetCompoundParametricStudyTool]':
        '''List[HypoidGearSetCompoundParametricStudyTool]: 'HypoidGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidGearSets, constructor.new(_4205.HypoidGearSetCompoundParametricStudyTool))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_sets(self) -> 'List[_4212.KlingelnbergCycloPalloidHypoidGearSetCompoundParametricStudyTool]':
        '''List[KlingelnbergCycloPalloidHypoidGearSetCompoundParametricStudyTool]: 'KlingelnbergCycloPalloidHypoidGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidGearSets, constructor.new(_4212.KlingelnbergCycloPalloidHypoidGearSetCompoundParametricStudyTool))
        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_sets(self) -> 'List[_4215.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundParametricStudyTool]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearSetCompoundParametricStudyTool]: 'KlingelnbergCycloPalloidSpiralBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSets, constructor.new(_4215.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundParametricStudyTool))
        return value

    @property
    def mass_discs(self) -> 'List[_4216.MassDiscCompoundParametricStudyTool]':
        '''List[MassDiscCompoundParametricStudyTool]: 'MassDiscs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MassDiscs, constructor.new(_4216.MassDiscCompoundParametricStudyTool))
        return value

    @property
    def measurement_components(self) -> 'List[_4217.MeasurementComponentCompoundParametricStudyTool]':
        '''List[MeasurementComponentCompoundParametricStudyTool]: 'MeasurementComponents' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeasurementComponents, constructor.new(_4217.MeasurementComponentCompoundParametricStudyTool))
        return value

    @property
    def oil_seals(self) -> 'List[_4219.OilSealCompoundParametricStudyTool]':
        '''List[OilSealCompoundParametricStudyTool]: 'OilSeals' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.OilSeals, constructor.new(_4219.OilSealCompoundParametricStudyTool))
        return value

    @property
    def part_to_part_shear_couplings(self) -> 'List[_4221.PartToPartShearCouplingCompoundParametricStudyTool]':
        '''List[PartToPartShearCouplingCompoundParametricStudyTool]: 'PartToPartShearCouplings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PartToPartShearCouplings, constructor.new(_4221.PartToPartShearCouplingCompoundParametricStudyTool))
        return value

    @property
    def planet_carriers(self) -> 'List[_4226.PlanetCarrierCompoundParametricStudyTool]':
        '''List[PlanetCarrierCompoundParametricStudyTool]: 'PlanetCarriers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PlanetCarriers, constructor.new(_4226.PlanetCarrierCompoundParametricStudyTool))
        return value

    @property
    def point_loads(self) -> 'List[_4227.PointLoadCompoundParametricStudyTool]':
        '''List[PointLoadCompoundParametricStudyTool]: 'PointLoads' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PointLoads, constructor.new(_4227.PointLoadCompoundParametricStudyTool))
        return value

    @property
    def power_loads(self) -> 'List[_4228.PowerLoadCompoundParametricStudyTool]':
        '''List[PowerLoadCompoundParametricStudyTool]: 'PowerLoads' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PowerLoads, constructor.new(_4228.PowerLoadCompoundParametricStudyTool))
        return value

    @property
    def shaft_hub_connections(self) -> 'List[_4237.ShaftHubConnectionCompoundParametricStudyTool]':
        '''List[ShaftHubConnectionCompoundParametricStudyTool]: 'ShaftHubConnections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ShaftHubConnections, constructor.new(_4237.ShaftHubConnectionCompoundParametricStudyTool))
        return value

    @property
    def ring_pins(self) -> 'List[_4230.RingPinsCompoundParametricStudyTool]':
        '''List[RingPinsCompoundParametricStudyTool]: 'RingPins' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.RingPins, constructor.new(_4230.RingPinsCompoundParametricStudyTool))
        return value

    @property
    def rolling_ring_assemblies(self) -> 'List[_4232.RollingRingAssemblyCompoundParametricStudyTool]':
        '''List[RollingRingAssemblyCompoundParametricStudyTool]: 'RollingRingAssemblies' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.RollingRingAssemblies, constructor.new(_4232.RollingRingAssemblyCompoundParametricStudyTool))
        return value

    @property
    def shafts(self) -> 'List[_4236.ShaftCompoundParametricStudyTool]':
        '''List[ShaftCompoundParametricStudyTool]: 'Shafts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Shafts, constructor.new(_4236.ShaftCompoundParametricStudyTool))
        return value

    @property
    def spiral_bevel_gear_sets(self) -> 'List[_4242.SpiralBevelGearSetCompoundParametricStudyTool]':
        '''List[SpiralBevelGearSetCompoundParametricStudyTool]: 'SpiralBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpiralBevelGearSets, constructor.new(_4242.SpiralBevelGearSetCompoundParametricStudyTool))
        return value

    @property
    def spring_dampers(self) -> 'List[_4243.SpringDamperCompoundParametricStudyTool]':
        '''List[SpringDamperCompoundParametricStudyTool]: 'SpringDampers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpringDampers, constructor.new(_4243.SpringDamperCompoundParametricStudyTool))
        return value

    @property
    def straight_bevel_diff_gear_sets(self) -> 'List[_4248.StraightBevelDiffGearSetCompoundParametricStudyTool]':
        '''List[StraightBevelDiffGearSetCompoundParametricStudyTool]: 'StraightBevelDiffGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffGearSets, constructor.new(_4248.StraightBevelDiffGearSetCompoundParametricStudyTool))
        return value

    @property
    def straight_bevel_gear_sets(self) -> 'List[_4251.StraightBevelGearSetCompoundParametricStudyTool]':
        '''List[StraightBevelGearSetCompoundParametricStudyTool]: 'StraightBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelGearSets, constructor.new(_4251.StraightBevelGearSetCompoundParametricStudyTool))
        return value

    @property
    def synchronisers(self) -> 'List[_4254.SynchroniserCompoundParametricStudyTool]':
        '''List[SynchroniserCompoundParametricStudyTool]: 'Synchronisers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Synchronisers, constructor.new(_4254.SynchroniserCompoundParametricStudyTool))
        return value

    @property
    def torque_converters(self) -> 'List[_4258.TorqueConverterCompoundParametricStudyTool]':
        '''List[TorqueConverterCompoundParametricStudyTool]: 'TorqueConverters' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.TorqueConverters, constructor.new(_4258.TorqueConverterCompoundParametricStudyTool))
        return value

    @property
    def unbalanced_masses(self) -> 'List[_4262.UnbalancedMassCompoundParametricStudyTool]':
        '''List[UnbalancedMassCompoundParametricStudyTool]: 'UnbalancedMasses' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.UnbalancedMasses, constructor.new(_4262.UnbalancedMassCompoundParametricStudyTool))
        return value

    @property
    def worm_gear_sets(self) -> 'List[_4266.WormGearSetCompoundParametricStudyTool]':
        '''List[WormGearSetCompoundParametricStudyTool]: 'WormGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormGearSets, constructor.new(_4266.WormGearSetCompoundParametricStudyTool))
        return value

    @property
    def zerol_bevel_gear_sets(self) -> 'List[_4269.ZerolBevelGearSetCompoundParametricStudyTool]':
        '''List[ZerolBevelGearSetCompoundParametricStudyTool]: 'ZerolBevelGearSets' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelGearSets, constructor.new(_4269.ZerolBevelGearSetCompoundParametricStudyTool))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_4001.AssemblyParametricStudyTool]':
        '''List[AssemblyParametricStudyTool]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_4001.AssemblyParametricStudyTool))
        return value



'''_696.py

CylindricalGearShaperTangible
'''


from mastapy._internal import constructor
from mastapy.gears.manufacturing.cylindrical.cutters import _684
from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _693
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SHAPER_TANGIBLE = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters.Tangibles', 'CylindricalGearShaperTangible')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearShaperTangible',)


class CylindricalGearShaperTangible(_693.CutterShapeDefinition):
    '''CylindricalGearShaperTangible

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_SHAPER_TANGIBLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearShaperTangible.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def edge_radius(self) -> 'float':
        '''float: 'EdgeRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EdgeRadius

    @property
    def single_circle_maximum_edge_radius(self) -> 'float':
        '''float: 'SingleCircleMaximumEdgeRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SingleCircleMaximumEdgeRadius

    @property
    def minimum_protuberance_height_for_single_circle(self) -> 'float':
        '''float: 'MinimumProtuberanceHeightForSingleCircle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumProtuberanceHeightForSingleCircle

    @property
    def maximum_protuberance_height_for_single_circle(self) -> 'float':
        '''float: 'MaximumProtuberanceHeightForSingleCircle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumProtuberanceHeightForSingleCircle

    @property
    def actual_protuberance(self) -> 'float':
        '''float: 'ActualProtuberance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ActualProtuberance

    @property
    def maximum_blade_control_distance(self) -> 'float':
        '''float: 'MaximumBladeControlDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumBladeControlDistance

    @property
    def maximum_tip_control_distance_for_zero_protuberance(self) -> 'float':
        '''float: 'MaximumTipControlDistanceForZeroProtuberance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumTipControlDistanceForZeroProtuberance

    @property
    def protuberance(self) -> 'float':
        '''float: 'Protuberance' is the original name of this property.'''

        return self.wrapped.Protuberance

    @protuberance.setter
    def protuberance(self, value: 'float'):
        self.wrapped.Protuberance = float(value) if value else 0.0

    @property
    def protuberance_angle(self) -> 'float':
        '''float: 'ProtuberanceAngle' is the original name of this property.'''

        return self.wrapped.ProtuberanceAngle

    @protuberance_angle.setter
    def protuberance_angle(self, value: 'float'):
        self.wrapped.ProtuberanceAngle = float(value) if value else 0.0

    @property
    def tip_diameter(self) -> 'float':
        '''float: 'TipDiameter' is the original name of this property.'''

        return self.wrapped.TipDiameter

    @tip_diameter.setter
    def tip_diameter(self, value: 'float'):
        self.wrapped.TipDiameter = float(value) if value else 0.0

    @property
    def root_diameter(self) -> 'float':
        '''float: 'RootDiameter' is the original name of this property.'''

        return self.wrapped.RootDiameter

    @root_diameter.setter
    def root_diameter(self, value: 'float'):
        self.wrapped.RootDiameter = float(value) if value else 0.0

    @property
    def helix_angle(self) -> 'float':
        '''float: 'HelixAngle' is the original name of this property.'''

        return self.wrapped.HelixAngle

    @helix_angle.setter
    def helix_angle(self, value: 'float'):
        self.wrapped.HelixAngle = float(value) if value else 0.0

    @property
    def protuberance_height(self) -> 'float':
        '''float: 'ProtuberanceHeight' is the original name of this property.'''

        return self.wrapped.ProtuberanceHeight

    @protuberance_height.setter
    def protuberance_height(self, value: 'float'):
        self.wrapped.ProtuberanceHeight = float(value) if value else 0.0

    @property
    def semi_topping_diameter(self) -> 'float':
        '''float: 'SemiToppingDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SemiToppingDiameter

    @property
    def tip_thickness(self) -> 'float':
        '''float: 'TipThickness' is the original name of this property.'''

        return self.wrapped.TipThickness

    @tip_thickness.setter
    def tip_thickness(self, value: 'float'):
        self.wrapped.TipThickness = float(value) if value else 0.0

    @property
    def normal_tooth_thickness(self) -> 'float':
        '''float: 'NormalToothThickness' is the original name of this property.'''

        return self.wrapped.NormalToothThickness

    @normal_tooth_thickness.setter
    def normal_tooth_thickness(self, value: 'float'):
        self.wrapped.NormalToothThickness = float(value) if value else 0.0

    @property
    def semi_topping_pressure_angle(self) -> 'float':
        '''float: 'SemiToppingPressureAngle' is the original name of this property.'''

        return self.wrapped.SemiToppingPressureAngle

    @semi_topping_pressure_angle.setter
    def semi_topping_pressure_angle(self, value: 'float'):
        self.wrapped.SemiToppingPressureAngle = float(value) if value else 0.0

    @property
    def base_diameter(self) -> 'float':
        '''float: 'BaseDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BaseDiameter

    @property
    def maximum_tip_diameter_to_avoid_pointed_teeth_no_protuberance(self) -> 'float':
        '''float: 'MaximumTipDiameterToAvoidPointedTeethNoProtuberance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumTipDiameterToAvoidPointedTeethNoProtuberance

    @property
    def minimum_protuberance_having_pointed_teeth(self) -> 'float':
        '''float: 'MinimumProtuberanceHavingPointedTeeth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumProtuberanceHavingPointedTeeth

    @property
    def maximum_protuberance(self) -> 'float':
        '''float: 'MaximumProtuberance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumProtuberance

    @property
    def design(self) -> '_684.CylindricalGearShaper':
        '''CylindricalGearShaper: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_684.CylindricalGearShaper)(self.wrapped.Design) if self.wrapped.Design else None



'''_115.py

ElementScalarState
'''


from mastapy.nodal_analysis.states import _116
from mastapy._internal.python_net import python_net_import

_ELEMENT_SCALAR_STATE = python_net_import('SMT.MastaAPI.NodalAnalysis.States', 'ElementScalarState')


__docformat__ = 'restructuredtext en'
__all__ = ('ElementScalarState',)


class ElementScalarState(_116.ElementVectorState):
    '''ElementScalarState

    This is a mastapy class.
    '''

    TYPE = _ELEMENT_SCALAR_STATE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElementScalarState.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1548.py

GearMeshForTE
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.utility.modal_analysis.gears import _1549, _1553
from mastapy._internal.python_net import python_net_import

_GEAR_MESH_FOR_TE = python_net_import('SMT.MastaAPI.Utility.ModalAnalysis.Gears', 'GearMeshForTE')


__docformat__ = 'restructuredtext en'
__all__ = ('GearMeshForTE',)


class GearMeshForTE(_1553.OrderForTE):
    '''GearMeshForTE

    This is a mastapy class.
    '''

    TYPE = _GEAR_MESH_FOR_TE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearMeshForTE.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def number_of_teeth(self) -> 'str':
        '''str: 'NumberOfTeeth' is the original name of this property.'''

        return self.wrapped.NumberOfTeeth

    @number_of_teeth.setter
    def number_of_teeth(self, value: 'str'):
        self.wrapped.NumberOfTeeth = str(value) if value else None

    @property
    def attached_gears(self) -> 'List[_1549.GearOrderForTE]':
        '''List[GearOrderForTE]: 'AttachedGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AttachedGears, constructor.new(_1549.GearOrderForTE))
        return value



'''_6563.py

ElectricMachineHarmonicLoadJMAGImportOptions
'''


from mastapy.system_model.analyses_and_results.static_loads import _6562
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_HARMONIC_LOAD_JMAG_IMPORT_OPTIONS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'ElectricMachineHarmonicLoadJMAGImportOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('ElectricMachineHarmonicLoadJMAGImportOptions',)


class ElectricMachineHarmonicLoadJMAGImportOptions(_6562.ElectricMachineHarmonicLoadImportOptionsBase):
    '''ElectricMachineHarmonicLoadJMAGImportOptions

    This is a mastapy class.
    '''

    TYPE = _ELECTRIC_MACHINE_HARMONIC_LOAD_JMAG_IMPORT_OPTIONS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElectricMachineHarmonicLoadJMAGImportOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_5662.py

ConceptGearSetHarmonicAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2229
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6524
from mastapy.system_model.analyses_and_results.system_deflections import _2423
from mastapy.system_model.analyses_and_results.harmonic_analyses import _5660, _5661, _5707
from mastapy._internal.python_net import python_net_import

_CONCEPT_GEAR_SET_HARMONIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses', 'ConceptGearSetHarmonicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptGearSetHarmonicAnalysis',)


class ConceptGearSetHarmonicAnalysis(_5707.GearSetHarmonicAnalysis):
    '''ConceptGearSetHarmonicAnalysis

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_GEAR_SET_HARMONIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptGearSetHarmonicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2229.ConceptGearSet':
        '''ConceptGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2229.ConceptGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6524.ConceptGearSetLoadCase':
        '''ConceptGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6524.ConceptGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def system_deflection_results(self) -> '_2423.ConceptGearSetSystemDeflection':
        '''ConceptGearSetSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2423.ConceptGearSetSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def gears_harmonic_analysis(self) -> 'List[_5660.ConceptGearHarmonicAnalysis]':
        '''List[ConceptGearHarmonicAnalysis]: 'GearsHarmonicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearsHarmonicAnalysis, constructor.new(_5660.ConceptGearHarmonicAnalysis))
        return value

    @property
    def concept_gears_harmonic_analysis(self) -> 'List[_5660.ConceptGearHarmonicAnalysis]':
        '''List[ConceptGearHarmonicAnalysis]: 'ConceptGearsHarmonicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptGearsHarmonicAnalysis, constructor.new(_5660.ConceptGearHarmonicAnalysis))
        return value

    @property
    def meshes_harmonic_analysis(self) -> 'List[_5661.ConceptGearMeshHarmonicAnalysis]':
        '''List[ConceptGearMeshHarmonicAnalysis]: 'MeshesHarmonicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshesHarmonicAnalysis, constructor.new(_5661.ConceptGearMeshHarmonicAnalysis))
        return value

    @property
    def concept_meshes_harmonic_analysis(self) -> 'List[_5661.ConceptGearMeshHarmonicAnalysis]':
        '''List[ConceptGearMeshHarmonicAnalysis]: 'ConceptMeshesHarmonicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptMeshesHarmonicAnalysis, constructor.new(_5661.ConceptGearMeshHarmonicAnalysis))
        return value



'''_537.py

BevelGearISOMaterial
'''


from mastapy.materials import _246
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy._internal.implicit import list_with_selected_item
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.gears.materials import _539
from mastapy._internal.python_net import python_net_import

_BEVEL_GEAR_ISO_MATERIAL = python_net_import('SMT.MastaAPI.Gears.Materials', 'BevelGearISOMaterial')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelGearISOMaterial',)


class BevelGearISOMaterial(_539.BevelGearMaterial):
    '''BevelGearISOMaterial

    This is a mastapy class.
    '''

    TYPE = _BEVEL_GEAR_ISO_MATERIAL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelGearISOMaterial.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def quality_grade(self) -> '_246.QualityGrade':
        '''QualityGrade: 'QualityGrade' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.QualityGrade)
        return constructor.new(_246.QualityGrade)(value) if value else None

    @quality_grade.setter
    def quality_grade(self, value: '_246.QualityGrade'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.QualityGrade = value

    @property
    def material_has_a_well_defined_yield_point(self) -> 'bool':
        '''bool: 'MaterialHasAWellDefinedYieldPoint' is the original name of this property.'''

        return self.wrapped.MaterialHasAWellDefinedYieldPoint

    @material_has_a_well_defined_yield_point.setter
    def material_has_a_well_defined_yield_point(self, value: 'bool'):
        self.wrapped.MaterialHasAWellDefinedYieldPoint = bool(value) if value else False

    @property
    def proof_stress(self) -> 'float':
        '''float: 'ProofStress' is the original name of this property.'''

        return self.wrapped.ProofStress

    @proof_stress.setter
    def proof_stress(self, value: 'float'):
        self.wrapped.ProofStress = float(value) if value else 0.0

    @property
    def iso_material_type(self) -> 'list_with_selected_item.ListWithSelectedItem_str':
        '''list_with_selected_item.ListWithSelectedItem_str: 'ISOMaterialType' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_str)(self.wrapped.ISOMaterialType) if self.wrapped.ISOMaterialType else None

    @iso_material_type.setter
    def iso_material_type(self, value: 'list_with_selected_item.ListWithSelectedItem_str.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else None)
        self.wrapped.ISOMaterialType = value

    @property
    def use_iso633652003_material_definitions(self) -> 'bool':
        '''bool: 'UseISO633652003MaterialDefinitions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.UseISO633652003MaterialDefinitions

    @property
    def limited_pitting_allowed(self) -> 'bool':
        '''bool: 'LimitedPittingAllowed' is the original name of this property.'''

        return self.wrapped.LimitedPittingAllowed

    @limited_pitting_allowed.setter
    def limited_pitting_allowed(self, value: 'bool'):
        self.wrapped.LimitedPittingAllowed = bool(value) if value else False

    @property
    def allowable_bending_stress(self) -> 'float':
        '''float: 'AllowableBendingStress' is the original name of this property.'''

        return self.wrapped.AllowableBendingStress

    @allowable_bending_stress.setter
    def allowable_bending_stress(self, value: 'float'):
        self.wrapped.AllowableBendingStress = float(value) if value else 0.0

    @property
    def allowable_contact_stress(self) -> 'float':
        '''float: 'AllowableContactStress' is the original name of this property.'''

        return self.wrapped.AllowableContactStress

    @allowable_contact_stress.setter
    def allowable_contact_stress(self, value: 'float'):
        self.wrapped.AllowableContactStress = float(value) if value else 0.0

    @property
    def specify_allowable_stress_numbers(self) -> 'bool':
        '''bool: 'SpecifyAllowableStressNumbers' is the original name of this property.'''

        return self.wrapped.SpecifyAllowableStressNumbers

    @specify_allowable_stress_numbers.setter
    def specify_allowable_stress_numbers(self, value: 'bool'):
        self.wrapped.SpecifyAllowableStressNumbers = bool(value) if value else False

    @property
    def long_life_life_factor_bending(self) -> 'float':
        '''float: 'LongLifeLifeFactorBending' is the original name of this property.'''

        return self.wrapped.LongLifeLifeFactorBending

    @long_life_life_factor_bending.setter
    def long_life_life_factor_bending(self, value: 'float'):
        self.wrapped.LongLifeLifeFactorBending = float(value) if value else 0.0

    @property
    def long_life_life_factor_contact(self) -> 'float':
        '''float: 'LongLifeLifeFactorContact' is the original name of this property.'''

        return self.wrapped.LongLifeLifeFactorContact

    @long_life_life_factor_contact.setter
    def long_life_life_factor_contact(self, value: 'float'):
        self.wrapped.LongLifeLifeFactorContact = float(value) if value else 0.0

    @property
    def n0_contact(self) -> 'float':
        '''float: 'N0Contact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.N0Contact

    @property
    def n0_bending(self) -> 'float':
        '''float: 'N0Bending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.N0Bending



'''_442.py

ScuffingIntegralTemperatureRatingMethod
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_SCUFFING_INTEGRAL_TEMPERATURE_RATING_METHOD = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical', 'ScuffingIntegralTemperatureRatingMethod')


__docformat__ = 'restructuredtext en'
__all__ = ('ScuffingIntegralTemperatureRatingMethod',)


class ScuffingIntegralTemperatureRatingMethod(Enum):
    '''ScuffingIntegralTemperatureRatingMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _SCUFFING_INTEGRAL_TEMPERATURE_RATING_METHOD

    __hash__ = None

    ISOTR_1398922000 = 0
    ISOTS_6336212017 = 1
    DIN_399041987 = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


ScuffingIntegralTemperatureRatingMethod.__setattr__ = __enum_setattr
ScuffingIntegralTemperatureRatingMethod.__delattr__ = __enum_delattr



'''_1997.py

PlanetarySocket
'''


from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets import _1998
from mastapy._internal.python_net import python_net_import

_PLANETARY_SOCKET = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets', 'PlanetarySocket')


__docformat__ = 'restructuredtext en'
__all__ = ('PlanetarySocket',)


class PlanetarySocket(_1998.PlanetarySocketBase):
    '''PlanetarySocket

    This is a mastapy class.
    '''

    TYPE = _PLANETARY_SOCKET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlanetarySocket.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def planet_tip_clearance(self) -> 'float':
        '''float: 'PlanetTipClearance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PlanetTipClearance



'''_2441.py

CylindricalGearMeshSystemDeflection
'''


from typing import List

from PIL.Image import Image

from mastapy._internal import constructor, conversion
from mastapy.system_model.connections_and_sockets.gears import _2018
from mastapy.system_model.analyses_and_results.static_loads import _6544
from mastapy.system_model.analyses_and_results.power_flows import _3780
from mastapy.gears.rating.cylindrical import _420
from mastapy.system_model.analyses_and_results.system_deflections import (
    _2447, _2448, _2449, _2452,
    _2451, _2461
)
from mastapy._internal.cast_exception import CastException
from mastapy.nodal_analysis import _52
from mastapy.system_model.analyses_and_results.system_deflections.reporting import _2547
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_MESH_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'CylindricalGearMeshSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearMeshSystemDeflection',)


class CylindricalGearMeshSystemDeflection(_2461.GearMeshSystemDeflection):
    '''CylindricalGearMeshSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_MESH_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearMeshSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def is_in_contact(self) -> 'bool':
        '''bool: 'IsInContact' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsInContact

    @property
    def pinion_torque_for_ltca(self) -> 'float':
        '''float: 'PinionTorqueForLTCA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionTorqueForLTCA

    @property
    def separation(self) -> 'float':
        '''float: 'Separation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Separation

    @property
    def separation_to_inactive_flank(self) -> 'float':
        '''float: 'SeparationToInactiveFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SeparationToInactiveFlank

    @property
    def load_in_loa_from_ltca(self) -> 'float':
        '''float: 'LoadInLOAFromLTCA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadInLOAFromLTCA

    @property
    def transmission_error_including_backlash(self) -> 'float':
        '''float: 'TransmissionErrorIncludingBacklash' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransmissionErrorIncludingBacklash

    @property
    def transmission_error_no_backlash(self) -> 'float':
        '''float: 'TransmissionErrorNoBacklash' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransmissionErrorNoBacklash

    @property
    def angular_misalignment_for_harmonic_analysis(self) -> 'float':
        '''float: 'AngularMisalignmentForHarmonicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AngularMisalignmentForHarmonicAnalysis

    @property
    def average_interference_normal_to_the_flank(self) -> 'float':
        '''float: 'AverageInterferenceNormalToTheFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AverageInterferenceNormalToTheFlank

    @property
    def estimated_operating_tooth_temperature(self) -> 'float':
        '''float: 'EstimatedOperatingToothTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EstimatedOperatingToothTemperature

    @property
    def minimum_operating_backlash(self) -> 'float':
        '''float: 'MinimumOperatingBacklash' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumOperatingBacklash

    @property
    def maximum_operating_backlash(self) -> 'float':
        '''float: 'MaximumOperatingBacklash' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumOperatingBacklash

    @property
    def average_operating_backlash(self) -> 'float':
        '''float: 'AverageOperatingBacklash' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AverageOperatingBacklash

    @property
    def change_in_operating_backlash_due_to_thermal_effects(self) -> 'float':
        '''float: 'ChangeInOperatingBacklashDueToThermalEffects' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ChangeInOperatingBacklashDueToThermalEffects

    @property
    def change_in_backlash_due_to_tooth_expansion(self) -> 'float':
        '''float: 'ChangeInBacklashDueToToothExpansion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ChangeInBacklashDueToToothExpansion

    @property
    def minimum_operating_centre_distance(self) -> 'float':
        '''float: 'MinimumOperatingCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumOperatingCentreDistance

    @property
    def maximum_operating_centre_distance(self) -> 'float':
        '''float: 'MaximumOperatingCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumOperatingCentreDistance

    @property
    def smallest_effective_operating_centre_distance(self) -> 'float':
        '''float: 'SmallestEffectiveOperatingCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SmallestEffectiveOperatingCentreDistance

    @property
    def minimum_change_in_centre_distance_due_to_misalignment(self) -> 'float':
        '''float: 'MinimumChangeInCentreDistanceDueToMisalignment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumChangeInCentreDistanceDueToMisalignment

    @property
    def maximum_change_in_centre_distance_due_to_misalignment(self) -> 'float':
        '''float: 'MaximumChangeInCentreDistanceDueToMisalignment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumChangeInCentreDistanceDueToMisalignment

    @property
    def node_pair_changes_in_operating_centre_distance_due_to_misalignment(self) -> 'List[float]':
        '''List[float]: 'NodePairChangesInOperatingCentreDistanceDueToMisalignment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_list_float(self.wrapped.NodePairChangesInOperatingCentreDistanceDueToMisalignment)
        return value

    @property
    def node_pair_transverse_separations_for_ltca(self) -> 'List[float]':
        '''List[float]: 'NodePairTransverseSeparationsForLTCA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_list_float(self.wrapped.NodePairTransverseSeparationsForLTCA)
        return value

    @property
    def minimum_change_in_centre_distance(self) -> 'float':
        '''float: 'MinimumChangeInCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumChangeInCentreDistance

    @property
    def maximum_change_in_centre_distance(self) -> 'float':
        '''float: 'MaximumChangeInCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumChangeInCentreDistance

    @property
    def minimum_operating_transverse_contact_ratio(self) -> 'float':
        '''float: 'MinimumOperatingTransverseContactRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumOperatingTransverseContactRatio

    @property
    def maximum_operating_transverse_contact_ratio(self) -> 'float':
        '''float: 'MaximumOperatingTransverseContactRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumOperatingTransverseContactRatio

    @property
    def chart_of_effective_change_in_operating_centre_distance(self) -> 'Image':
        '''Image: 'ChartOfEffectiveChangeInOperatingCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.ChartOfEffectiveChangeInOperatingCentreDistance)
        return value

    @property
    def signed_root_mean_square_planetary_equivalent_misalignment(self) -> 'float':
        '''float: 'SignedRootMeanSquarePlanetaryEquivalentMisalignment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SignedRootMeanSquarePlanetaryEquivalentMisalignment

    @property
    def worst_planetary_misalignment(self) -> 'float':
        '''float: 'WorstPlanetaryMisalignment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WorstPlanetaryMisalignment

    @property
    def calculated_worst_load_sharing_factor(self) -> 'float':
        '''float: 'CalculatedWorstLoadSharingFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CalculatedWorstLoadSharingFactor

    @property
    def calculated_load_sharing_factor(self) -> 'float':
        '''float: 'CalculatedLoadSharingFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CalculatedLoadSharingFactor

    @property
    def gear_mesh_tilt_stiffness_method(self) -> 'str':
        '''str: 'GearMeshTiltStiffnessMethod' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GearMeshTiltStiffnessMethod

    @property
    def crowning_for_tilt_stiffness_gear_a(self) -> 'float':
        '''float: 'CrowningForTiltStiffnessGearA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CrowningForTiltStiffnessGearA

    @property
    def crowning_for_tilt_stiffness_gear_b(self) -> 'float':
        '''float: 'CrowningForTiltStiffnessGearB' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CrowningForTiltStiffnessGearB

    @property
    def linear_relief_for_tilt_stiffness_gear_a(self) -> 'float':
        '''float: 'LinearReliefForTiltStiffnessGearA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LinearReliefForTiltStiffnessGearA

    @property
    def linear_relief_for_tilt_stiffness_gear_b(self) -> 'float':
        '''float: 'LinearReliefForTiltStiffnessGearB' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LinearReliefForTiltStiffnessGearB

    @property
    def connection_design(self) -> '_2018.CylindricalGearMesh':
        '''CylindricalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2018.CylindricalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6544.CylindricalGearMeshLoadCase':
        '''CylindricalGearMeshLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6544.CylindricalGearMeshLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None

    @property
    def power_flow_results(self) -> '_3780.CylindricalGearMeshPowerFlow':
        '''CylindricalGearMeshPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_3780.CylindricalGearMeshPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def rating(self) -> '_420.CylindricalGearMeshRating':
        '''CylindricalGearMeshRating: 'Rating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_420.CylindricalGearMeshRating)(self.wrapped.Rating) if self.wrapped.Rating else None

    @property
    def component_detailed_analysis(self) -> '_420.CylindricalGearMeshRating':
        '''CylindricalGearMeshRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_420.CylindricalGearMeshRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None

    @property
    def gear_a(self) -> '_2447.CylindricalGearSystemDeflection':
        '''CylindricalGearSystemDeflection: 'GearA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2447.CylindricalGearSystemDeflection.TYPE not in self.wrapped.GearA.__class__.__mro__:
            raise CastException('Failed to cast gear_a to CylindricalGearSystemDeflection. Expected: {}.'.format(self.wrapped.GearA.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearA.__class__)(self.wrapped.GearA) if self.wrapped.GearA else None

    @property
    def gear_a_of_type_cylindrical_gear_system_deflection_timestep(self) -> '_2448.CylindricalGearSystemDeflectionTimestep':
        '''CylindricalGearSystemDeflectionTimestep: 'GearA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2448.CylindricalGearSystemDeflectionTimestep.TYPE not in self.wrapped.GearA.__class__.__mro__:
            raise CastException('Failed to cast gear_a to CylindricalGearSystemDeflectionTimestep. Expected: {}.'.format(self.wrapped.GearA.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearA.__class__)(self.wrapped.GearA) if self.wrapped.GearA else None

    @property
    def gear_a_of_type_cylindrical_gear_system_deflection_with_ltca_results(self) -> '_2449.CylindricalGearSystemDeflectionWithLTCAResults':
        '''CylindricalGearSystemDeflectionWithLTCAResults: 'GearA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2449.CylindricalGearSystemDeflectionWithLTCAResults.TYPE not in self.wrapped.GearA.__class__.__mro__:
            raise CastException('Failed to cast gear_a to CylindricalGearSystemDeflectionWithLTCAResults. Expected: {}.'.format(self.wrapped.GearA.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearA.__class__)(self.wrapped.GearA) if self.wrapped.GearA else None

    @property
    def gear_a_of_type_cylindrical_planet_gear_system_deflection(self) -> '_2452.CylindricalPlanetGearSystemDeflection':
        '''CylindricalPlanetGearSystemDeflection: 'GearA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2452.CylindricalPlanetGearSystemDeflection.TYPE not in self.wrapped.GearA.__class__.__mro__:
            raise CastException('Failed to cast gear_a to CylindricalPlanetGearSystemDeflection. Expected: {}.'.format(self.wrapped.GearA.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearA.__class__)(self.wrapped.GearA) if self.wrapped.GearA else None

    @property
    def gear_b(self) -> '_2447.CylindricalGearSystemDeflection':
        '''CylindricalGearSystemDeflection: 'GearB' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2447.CylindricalGearSystemDeflection.TYPE not in self.wrapped.GearB.__class__.__mro__:
            raise CastException('Failed to cast gear_b to CylindricalGearSystemDeflection. Expected: {}.'.format(self.wrapped.GearB.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearB.__class__)(self.wrapped.GearB) if self.wrapped.GearB else None

    @property
    def gear_b_of_type_cylindrical_gear_system_deflection_timestep(self) -> '_2448.CylindricalGearSystemDeflectionTimestep':
        '''CylindricalGearSystemDeflectionTimestep: 'GearB' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2448.CylindricalGearSystemDeflectionTimestep.TYPE not in self.wrapped.GearB.__class__.__mro__:
            raise CastException('Failed to cast gear_b to CylindricalGearSystemDeflectionTimestep. Expected: {}.'.format(self.wrapped.GearB.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearB.__class__)(self.wrapped.GearB) if self.wrapped.GearB else None

    @property
    def gear_b_of_type_cylindrical_gear_system_deflection_with_ltca_results(self) -> '_2449.CylindricalGearSystemDeflectionWithLTCAResults':
        '''CylindricalGearSystemDeflectionWithLTCAResults: 'GearB' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2449.CylindricalGearSystemDeflectionWithLTCAResults.TYPE not in self.wrapped.GearB.__class__.__mro__:
            raise CastException('Failed to cast gear_b to CylindricalGearSystemDeflectionWithLTCAResults. Expected: {}.'.format(self.wrapped.GearB.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearB.__class__)(self.wrapped.GearB) if self.wrapped.GearB else None

    @property
    def gear_b_of_type_cylindrical_planet_gear_system_deflection(self) -> '_2452.CylindricalPlanetGearSystemDeflection':
        '''CylindricalPlanetGearSystemDeflection: 'GearB' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2452.CylindricalPlanetGearSystemDeflection.TYPE not in self.wrapped.GearB.__class__.__mro__:
            raise CastException('Failed to cast gear_b to CylindricalPlanetGearSystemDeflection. Expected: {}.'.format(self.wrapped.GearB.__class__.__qualname__))

        return constructor.new_override(self.wrapped.GearB.__class__)(self.wrapped.GearB) if self.wrapped.GearB else None

    @property
    def misalignment_data(self) -> '_52.CylindricalMisalignmentCalculator':
        '''CylindricalMisalignmentCalculator: 'MisalignmentData' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_52.CylindricalMisalignmentCalculator)(self.wrapped.MisalignmentData) if self.wrapped.MisalignmentData else None

    @property
    def misalignment_data_left_flank(self) -> '_52.CylindricalMisalignmentCalculator':
        '''CylindricalMisalignmentCalculator: 'MisalignmentDataLeftFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_52.CylindricalMisalignmentCalculator)(self.wrapped.MisalignmentDataLeftFlank) if self.wrapped.MisalignmentDataLeftFlank else None

    @property
    def misalignment_data_right_flank(self) -> '_52.CylindricalMisalignmentCalculator':
        '''CylindricalMisalignmentCalculator: 'MisalignmentDataRightFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_52.CylindricalMisalignmentCalculator)(self.wrapped.MisalignmentDataRightFlank) if self.wrapped.MisalignmentDataRightFlank else None

    @property
    def planetaries(self) -> 'List[CylindricalGearMeshSystemDeflection]':
        '''List[CylindricalGearMeshSystemDeflection]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(CylindricalGearMeshSystemDeflection))
        return value

    @property
    def cylindrical_gears(self) -> 'List[_2447.CylindricalGearSystemDeflection]':
        '''List[CylindricalGearSystemDeflection]: 'CylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalGears, constructor.new(_2447.CylindricalGearSystemDeflection))
        return value

    @property
    def cylindrical_meshed_gear_system_deflections(self) -> 'List[_2451.CylindricalMeshedGearSystemDeflection]':
        '''List[CylindricalMeshedGearSystemDeflection]: 'CylindricalMeshedGearSystemDeflections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalMeshedGearSystemDeflections, constructor.new(_2451.CylindricalMeshedGearSystemDeflection))
        return value

    @property
    def mesh_deflections_left_flank(self) -> 'List[_2547.MeshDeflectionResults]':
        '''List[MeshDeflectionResults]: 'MeshDeflectionsLeftFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshDeflectionsLeftFlank, constructor.new(_2547.MeshDeflectionResults))
        return value

    @property
    def mesh_deflections_right_flank(self) -> 'List[_2547.MeshDeflectionResults]':
        '''List[MeshDeflectionResults]: 'MeshDeflectionsRightFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshDeflectionsRightFlank, constructor.new(_2547.MeshDeflectionResults))
        return value



'''_1204.py

SAESplineTolerances
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SAE_SPLINE_TOLERANCES = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines.TolerancesAndDeviations', 'SAESplineTolerances')


__docformat__ = 'restructuredtext en'
__all__ = ('SAESplineTolerances',)


class SAESplineTolerances(_0.APIBase):
    '''SAESplineTolerances

    This is a mastapy class.
    '''

    TYPE = _SAE_SPLINE_TOLERANCES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SAESplineTolerances.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def variation_tolerance(self) -> 'float':
        '''float: 'VariationTolerance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VariationTolerance

    @property
    def lead_variation(self) -> 'float':
        '''float: 'LeadVariation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LeadVariation

    @property
    def profile_variation_f_fp(self) -> 'float':
        '''float: 'ProfileVariationF_fp' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ProfileVariationF_fp

    @property
    def profile_variation_f_fm(self) -> 'float':
        '''float: 'ProfileVariationF_fm' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ProfileVariationF_fm

    @property
    def total_index_variation(self) -> 'float':
        '''float: 'TotalIndexVariation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalIndexVariation

    @property
    def machining_variation(self) -> 'float':
        '''float: 'MachiningVariation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MachiningVariation

    @property
    def major_diameter_tolerance(self) -> 'float':
        '''float: 'MajorDiameterTolerance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MajorDiameterTolerance

    @property
    def minor_diameter_tolerance(self) -> 'float':
        '''float: 'MinorDiameterTolerance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinorDiameterTolerance

    @property
    def internal_major_diameter_tolerance(self) -> 'float':
        '''float: 'InternalMajorDiameterTolerance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InternalMajorDiameterTolerance

    @property
    def multiplier_f(self) -> 'float':
        '''float: 'MultiplierF' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MultiplierF



'''_398.py

ISO10300SingleFlankRatingMethodB2
'''


from mastapy._internal import constructor
from mastapy.gears.rating.iso_10300 import _394
from mastapy.gears.rating.virtual_cylindrical_gears import _356
from mastapy._internal.python_net import python_net_import

_ISO10300_SINGLE_FLANK_RATING_METHOD_B2 = python_net_import('SMT.MastaAPI.Gears.Rating.Iso10300', 'ISO10300SingleFlankRatingMethodB2')


__docformat__ = 'restructuredtext en'
__all__ = ('ISO10300SingleFlankRatingMethodB2',)


class ISO10300SingleFlankRatingMethodB2(_394.ISO10300SingleFlankRating['_356.VirtualCylindricalGearISO10300MethodB2']):
    '''ISO10300SingleFlankRatingMethodB2

    This is a mastapy class.
    '''

    TYPE = _ISO10300_SINGLE_FLANK_RATING_METHOD_B2

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ISO10300SingleFlankRatingMethodB2.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def permissible_contact_stress_method_b2(self) -> 'float':
        '''float: 'PermissibleContactStressMethodB2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleContactStressMethodB2

    @property
    def safety_factor_contact_for_method_b2(self) -> 'float':
        '''float: 'SafetyFactorContactForMethodB2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorContactForMethodB2

    @property
    def cos_pressure_angle_at_point_of_load_application(self) -> 'float':
        '''float: 'CosPressureAngleAtPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CosPressureAngleAtPointOfLoadApplication

    @property
    def pressure_angle_at_point_of_load_application(self) -> 'float':
        '''float: 'PressureAngleAtPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PressureAngleAtPointOfLoadApplication

    @property
    def radius_of_curvature_difference_between_point_of_load_and_mean_point(self) -> 'float':
        '''float: 'RadiusOfCurvatureDifferenceBetweenPointOfLoadAndMeanPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RadiusOfCurvatureDifferenceBetweenPointOfLoadAndMeanPoint

    @property
    def contact_stress_adjustment_factor(self) -> 'float':
        '''float: 'ContactStressAdjustmentFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactStressAdjustmentFactor

    @property
    def tooth_root_stress_method_b2(self) -> 'float':
        '''float: 'ToothRootStressMethodB2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootStressMethodB2

    @property
    def nominal_value_of_root_stress_method_b2(self) -> 'float':
        '''float: 'NominalValueOfRootStressMethodB2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NominalValueOfRootStressMethodB2

    @property
    def combined_geometry_factor(self) -> 'float':
        '''float: 'CombinedGeometryFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CombinedGeometryFactor

    @property
    def permissible_tooth_root_stress_method_b2(self) -> 'float':
        '''float: 'PermissibleToothRootStressMethodB2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PermissibleToothRootStressMethodB2

    @property
    def safety_factor_bending_for_method_b2(self) -> 'float':
        '''float: 'SafetyFactorBendingForMethodB2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorBendingForMethodB2

    @property
    def geometry_factor(self) -> 'float':
        '''float: 'GeometryFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GeometryFactor

    @property
    def relative_fillet_radius_at_root_of_tooth(self) -> 'float':
        '''float: 'RelativeFilletRadiusAtRootOfTooth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RelativeFilletRadiusAtRootOfTooth

    @property
    def stress_concentration_and_correction_factor(self) -> 'float':
        '''float: 'StressConcentrationAndCorrectionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressConcentrationAndCorrectionFactor

    @property
    def L(self) -> 'float':
        '''float: 'L' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.L

    @property
    def m(self) -> 'float':
        '''float: 'M' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.M

    @property
    def o(self) -> 'float':
        '''float: 'O' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.O

    @property
    def inertia_factor(self) -> 'float':
        '''float: 'InertiaFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InertiaFactor

    @property
    def projected_length_of_the_instantaneous_contact_line_in_the_tooth_lengthwise_direction(self) -> 'float':
        '''float: 'ProjectedLengthOfTheInstantaneousContactLineInTheToothLengthwiseDirection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ProjectedLengthOfTheInstantaneousContactLineInTheToothLengthwiseDirection

    @property
    def toe_increment(self) -> 'float':
        '''float: 'ToeIncrement' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToeIncrement

    @property
    def heel_increment(self) -> 'float':
        '''float: 'HeelIncrement' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HeelIncrement

    @property
    def toe_increment_delta_bi(self) -> 'float':
        '''float: 'ToeIncrementDeltaBi' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToeIncrementDeltaBi

    @property
    def heel_increment_delta_be(self) -> 'float':
        '''float: 'HeelIncrementDeltaBe' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HeelIncrementDeltaBe

    @property
    def effective_face_width(self) -> 'float':
        '''float: 'EffectiveFaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EffectiveFaceWidth

    @property
    def root_stress_adjustment_factor(self) -> 'float':
        '''float: 'RootStressAdjustmentFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RootStressAdjustmentFactor

    @property
    def relative_surface_condition_factor_for_method_b2(self) -> 'float':
        '''float: 'RelativeSurfaceConditionFactorForMethodB2' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RelativeSurfaceConditionFactorForMethodB2

    @property
    def relative_notch_sensitivity_factor(self) -> 'float':
        '''float: 'RelativeNotchSensitivityFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RelativeNotchSensitivityFactor



'''_5052.py

StraightBevelSunGearCompoundModalAnalysis
'''


from typing import List

from mastapy.system_model.analyses_and_results.modal_analyses import _4906
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.modal_analyses.compound import _5045
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_SUN_GEAR_COMPOUND_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Compound', 'StraightBevelSunGearCompoundModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelSunGearCompoundModalAnalysis',)


class StraightBevelSunGearCompoundModalAnalysis(_5045.StraightBevelDiffGearCompoundModalAnalysis):
    '''StraightBevelSunGearCompoundModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_SUN_GEAR_COMPOUND_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelSunGearCompoundModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_analysis_cases_ready(self) -> 'List[_4906.StraightBevelSunGearModalAnalysis]':
        '''List[StraightBevelSunGearModalAnalysis]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_4906.StraightBevelSunGearModalAnalysis))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_4906.StraightBevelSunGearModalAnalysis]':
        '''List[StraightBevelSunGearModalAnalysis]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_4906.StraightBevelSunGearModalAnalysis))
        return value



'''_2277.py

RingPins
'''


from mastapy._internal.python_net import python_net_import
from mastapy._internal import constructor
from mastapy.cycloidal import _1242, _1243
from mastapy.system_model.part_model import _2172

_DATABASE_WITH_SELECTED_ITEM = python_net_import('SMT.MastaAPI.UtilityGUI.Databases', 'DatabaseWithSelectedItem')
_RING_PINS = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Cycloidal', 'RingPins')


__docformat__ = 'restructuredtext en'
__all__ = ('RingPins',)


class RingPins(_2172.MountableComponent):
    '''RingPins

    This is a mastapy class.
    '''

    TYPE = _RING_PINS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RingPins.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def ring_pins_material_database(self) -> 'str':
        '''str: 'RingPinsMaterialDatabase' is the original name of this property.'''

        return self.wrapped.RingPinsMaterialDatabase.SelectedItemName

    @ring_pins_material_database.setter
    def ring_pins_material_database(self, value: 'str'):
        self.wrapped.RingPinsMaterialDatabase.SetSelectedItem(str(value) if value else None)

    @property
    def length(self) -> 'float':
        '''float: 'Length' is the original name of this property.'''

        return self.wrapped.Length

    @length.setter
    def length(self, value: 'float'):
        self.wrapped.Length = float(value) if value else 0.0

    @property
    def ring_pins_design(self) -> '_1242.RingPinsDesign':
        '''RingPinsDesign: 'RingPinsDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1242.RingPinsDesign)(self.wrapped.RingPinsDesign) if self.wrapped.RingPinsDesign else None

    @property
    def ring_pins_material(self) -> '_1243.RingPinsMaterial':
        '''RingPinsMaterial: 'RingPinsMaterial' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1243.RingPinsMaterial)(self.wrapped.RingPinsMaterial) if self.wrapped.RingPinsMaterial else None



'''_534.py

ProfileModification
'''


from mastapy._internal.implicit import enum_with_selected_value
from mastapy.gears.micro_geometry import (
    _528, _530, _533, _527,
    _529, _532, _526, _525,
    _531
)
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy.math_utility import _1315
from mastapy._internal.python_net import python_net_import

_PROFILE_MODIFICATION = python_net_import('SMT.MastaAPI.Gears.MicroGeometry', 'ProfileModification')


__docformat__ = 'restructuredtext en'
__all__ = ('ProfileModification',)


class ProfileModification(_531.Modification):
    '''ProfileModification

    This is a mastapy class.
    '''

    TYPE = _PROFILE_MODIFICATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ProfileModification.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def location_of_tip_relief_start(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation: 'LocationOfTipReliefStart' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfTipReliefStart, value) if self.wrapped.LocationOfTipReliefStart else None

    @location_of_tip_relief_start.setter
    def location_of_tip_relief_start(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfTipReliefStart = value

    @property
    def main_profile_modification_ends_at_the_start_of_tip_relief(self) -> '_530.MainProfileReliefEndsAtTheStartOfTipReliefOption':
        '''MainProfileReliefEndsAtTheStartOfTipReliefOption: 'MainProfileModificationEndsAtTheStartOfTipRelief' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.MainProfileModificationEndsAtTheStartOfTipRelief)
        return constructor.new(_530.MainProfileReliefEndsAtTheStartOfTipReliefOption)(value) if value else None

    @main_profile_modification_ends_at_the_start_of_tip_relief.setter
    def main_profile_modification_ends_at_the_start_of_tip_relief(self, value: '_530.MainProfileReliefEndsAtTheStartOfTipReliefOption'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.MainProfileModificationEndsAtTheStartOfTipRelief = value

    @property
    def measure_tip_reliefs_from_extrapolated_linear_relief(self) -> 'bool':
        '''bool: 'MeasureTipReliefsFromExtrapolatedLinearRelief' is the original name of this property.'''

        return self.wrapped.MeasureTipReliefsFromExtrapolatedLinearRelief

    @measure_tip_reliefs_from_extrapolated_linear_relief.setter
    def measure_tip_reliefs_from_extrapolated_linear_relief(self, value: 'bool'):
        self.wrapped.MeasureTipReliefsFromExtrapolatedLinearRelief = bool(value) if value else False

    @property
    def location_of_tip_relief_evaluation(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation: 'LocationOfTipReliefEvaluation' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfTipReliefEvaluation, value) if self.wrapped.LocationOfTipReliefEvaluation else None

    @location_of_tip_relief_evaluation.setter
    def location_of_tip_relief_evaluation(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfTipReliefEvaluation.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfTipReliefEvaluation = value

    @property
    def evaluation_of_linear_tip_relief_factor(self) -> 'float':
        '''float: 'EvaluationOfLinearTipReliefFactor' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearTipReliefFactor

    @evaluation_of_linear_tip_relief_factor.setter
    def evaluation_of_linear_tip_relief_factor(self, value: 'float'):
        self.wrapped.EvaluationOfLinearTipReliefFactor = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_tip_relief_factor(self) -> 'float':
        '''float: 'EvaluationOfParabolicTipReliefFactor' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicTipReliefFactor

    @evaluation_of_parabolic_tip_relief_factor.setter
    def evaluation_of_parabolic_tip_relief_factor(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicTipReliefFactor = float(value) if value else 0.0

    @property
    def parabolic_tip_relief_starts_tangent_to_main_profile_relief(self) -> '_533.ParabolicTipReliefStartsTangentToMainProfileRelief':
        '''ParabolicTipReliefStartsTangentToMainProfileRelief: 'ParabolicTipReliefStartsTangentToMainProfileRelief' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.ParabolicTipReliefStartsTangentToMainProfileRelief)
        return constructor.new(_533.ParabolicTipReliefStartsTangentToMainProfileRelief)(value) if value else None

    @parabolic_tip_relief_starts_tangent_to_main_profile_relief.setter
    def parabolic_tip_relief_starts_tangent_to_main_profile_relief(self, value: '_533.ParabolicTipReliefStartsTangentToMainProfileRelief'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ParabolicTipReliefStartsTangentToMainProfileRelief = value

    @property
    def location_of_root_modification_start(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation: 'LocationOfRootModificationStart' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfRootModificationStart, value) if self.wrapped.LocationOfRootModificationStart else None

    @location_of_root_modification_start.setter
    def location_of_root_modification_start(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfRootModificationStart = value

    @property
    def main_profile_modification_ends_at_the_start_of_root_relief(self) -> '_529.MainProfileReliefEndsAtTheStartOfRootReliefOption':
        '''MainProfileReliefEndsAtTheStartOfRootReliefOption: 'MainProfileModificationEndsAtTheStartOfRootRelief' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.MainProfileModificationEndsAtTheStartOfRootRelief)
        return constructor.new(_529.MainProfileReliefEndsAtTheStartOfRootReliefOption)(value) if value else None

    @main_profile_modification_ends_at_the_start_of_root_relief.setter
    def main_profile_modification_ends_at_the_start_of_root_relief(self, value: '_529.MainProfileReliefEndsAtTheStartOfRootReliefOption'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.MainProfileModificationEndsAtTheStartOfRootRelief = value

    @property
    def measure_root_reliefs_from_extrapolated_linear_relief(self) -> 'bool':
        '''bool: 'MeasureRootReliefsFromExtrapolatedLinearRelief' is the original name of this property.'''

        return self.wrapped.MeasureRootReliefsFromExtrapolatedLinearRelief

    @measure_root_reliefs_from_extrapolated_linear_relief.setter
    def measure_root_reliefs_from_extrapolated_linear_relief(self, value: 'bool'):
        self.wrapped.MeasureRootReliefsFromExtrapolatedLinearRelief = bool(value) if value else False

    @property
    def location_of_root_relief_evaluation(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation: 'LocationOfRootReliefEvaluation' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfRootReliefEvaluation, value) if self.wrapped.LocationOfRootReliefEvaluation else None

    @location_of_root_relief_evaluation.setter
    def location_of_root_relief_evaluation(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfRootReliefEvaluation.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfRootReliefEvaluation = value

    @property
    def evaluation_of_linear_root_relief_factor(self) -> 'float':
        '''float: 'EvaluationOfLinearRootReliefFactor' is the original name of this property.'''

        return self.wrapped.EvaluationOfLinearRootReliefFactor

    @evaluation_of_linear_root_relief_factor.setter
    def evaluation_of_linear_root_relief_factor(self, value: 'float'):
        self.wrapped.EvaluationOfLinearRootReliefFactor = float(value) if value else 0.0

    @property
    def evaluation_of_parabolic_root_relief_factor(self) -> 'float':
        '''float: 'EvaluationOfParabolicRootReliefFactor' is the original name of this property.'''

        return self.wrapped.EvaluationOfParabolicRootReliefFactor

    @evaluation_of_parabolic_root_relief_factor.setter
    def evaluation_of_parabolic_root_relief_factor(self, value: 'float'):
        self.wrapped.EvaluationOfParabolicRootReliefFactor = float(value) if value else 0.0

    @property
    def parabolic_root_relief_starts_tangent_to_main_profile_relief(self) -> '_532.ParabolicRootReliefStartsTangentToMainProfileRelief':
        '''ParabolicRootReliefStartsTangentToMainProfileRelief: 'ParabolicRootReliefStartsTangentToMainProfileRelief' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.ParabolicRootReliefStartsTangentToMainProfileRelief)
        return constructor.new(_532.ParabolicRootReliefStartsTangentToMainProfileRelief)(value) if value else None

    @parabolic_root_relief_starts_tangent_to_main_profile_relief.setter
    def parabolic_root_relief_starts_tangent_to_main_profile_relief(self, value: '_532.ParabolicRootReliefStartsTangentToMainProfileRelief'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.ParabolicRootReliefStartsTangentToMainProfileRelief = value

    @property
    def linear_relief(self) -> 'float':
        '''float: 'LinearRelief' is the original name of this property.'''

        return self.wrapped.LinearRelief

    @linear_relief.setter
    def linear_relief(self, value: 'float'):
        self.wrapped.LinearRelief = float(value) if value else 0.0

    @property
    def barrelling_relief(self) -> 'float':
        '''float: 'BarrellingRelief' is the original name of this property.'''

        return self.wrapped.BarrellingRelief

    @barrelling_relief.setter
    def barrelling_relief(self, value: 'float'):
        self.wrapped.BarrellingRelief = float(value) if value else 0.0

    @property
    def linear_root_relief(self) -> 'float':
        '''float: 'LinearRootRelief' is the original name of this property.'''

        return self.wrapped.LinearRootRelief

    @linear_root_relief.setter
    def linear_root_relief(self, value: 'float'):
        self.wrapped.LinearRootRelief = float(value) if value else 0.0

    @property
    def parabolic_root_relief(self) -> 'float':
        '''float: 'ParabolicRootRelief' is the original name of this property.'''

        return self.wrapped.ParabolicRootRelief

    @parabolic_root_relief.setter
    def parabolic_root_relief(self, value: 'float'):
        self.wrapped.ParabolicRootRelief = float(value) if value else 0.0

    @property
    def linear_tip_relief(self) -> 'float':
        '''float: 'LinearTipRelief' is the original name of this property.'''

        return self.wrapped.LinearTipRelief

    @linear_tip_relief.setter
    def linear_tip_relief(self, value: 'float'):
        self.wrapped.LinearTipRelief = float(value) if value else 0.0

    @property
    def parabolic_tip_relief(self) -> 'float':
        '''float: 'ParabolicTipRelief' is the original name of this property.'''

        return self.wrapped.ParabolicTipRelief

    @parabolic_tip_relief.setter
    def parabolic_tip_relief(self, value: 'float'):
        self.wrapped.ParabolicTipRelief = float(value) if value else 0.0

    @property
    def location_of_evaluation_upper_limit_for_zero_tip_relief(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit: 'LocationOfEvaluationUpperLimitForZeroTipRelief' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfEvaluationUpperLimitForZeroTipRelief, value) if self.wrapped.LocationOfEvaluationUpperLimitForZeroTipRelief else None

    @location_of_evaluation_upper_limit_for_zero_tip_relief.setter
    def location_of_evaluation_upper_limit_for_zero_tip_relief(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfEvaluationUpperLimitForZeroTipRelief = value

    @property
    def evaluation_upper_limit_factor_for_zero_tip_relief(self) -> 'float':
        '''float: 'EvaluationUpperLimitFactorForZeroTipRelief' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitFactorForZeroTipRelief

    @evaluation_upper_limit_factor_for_zero_tip_relief.setter
    def evaluation_upper_limit_factor_for_zero_tip_relief(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitFactorForZeroTipRelief = float(value) if value else 0.0

    @property
    def location_of_evaluation_upper_limit(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit: 'LocationOfEvaluationUpperLimit' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfEvaluationUpperLimit, value) if self.wrapped.LocationOfEvaluationUpperLimit else None

    @location_of_evaluation_upper_limit.setter
    def location_of_evaluation_upper_limit(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationUpperLimit.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfEvaluationUpperLimit = value

    @property
    def evaluation_upper_limit_factor(self) -> 'float':
        '''float: 'EvaluationUpperLimitFactor' is the original name of this property.'''

        return self.wrapped.EvaluationUpperLimitFactor

    @evaluation_upper_limit_factor.setter
    def evaluation_upper_limit_factor(self, value: 'float'):
        self.wrapped.EvaluationUpperLimitFactor = float(value) if value else 0.0

    @property
    def location_of_evaluation_lower_limit_for_zero_root_relief(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit: 'LocationOfEvaluationLowerLimitForZeroRootRelief' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfEvaluationLowerLimitForZeroRootRelief, value) if self.wrapped.LocationOfEvaluationLowerLimitForZeroRootRelief else None

    @location_of_evaluation_lower_limit_for_zero_root_relief.setter
    def location_of_evaluation_lower_limit_for_zero_root_relief(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfEvaluationLowerLimitForZeroRootRelief = value

    @property
    def evaluation_lower_limit_factor_for_zero_root_relief(self) -> 'float':
        '''float: 'EvaluationLowerLimitFactorForZeroRootRelief' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitFactorForZeroRootRelief

    @evaluation_lower_limit_factor_for_zero_root_relief.setter
    def evaluation_lower_limit_factor_for_zero_root_relief(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitFactorForZeroRootRelief = float(value) if value else 0.0

    @property
    def location_of_evaluation_lower_limit(self) -> 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit':
        '''enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit: 'LocationOfEvaluationLowerLimit' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LocationOfEvaluationLowerLimit, value) if self.wrapped.LocationOfEvaluationLowerLimit else None

    @location_of_evaluation_lower_limit.setter
    def location_of_evaluation_lower_limit(self, value: 'enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LocationOfEvaluationLowerLimit.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LocationOfEvaluationLowerLimit = value

    @property
    def evaluation_lower_limit_factor(self) -> 'float':
        '''float: 'EvaluationLowerLimitFactor' is the original name of this property.'''

        return self.wrapped.EvaluationLowerLimitFactor

    @evaluation_lower_limit_factor.setter
    def evaluation_lower_limit_factor(self, value: 'float'):
        self.wrapped.EvaluationLowerLimitFactor = float(value) if value else 0.0

    @property
    def start_of_linear_tip_relief_factor(self) -> 'float':
        '''float: 'StartOfLinearTipReliefFactor' is the original name of this property.'''

        return self.wrapped.StartOfLinearTipReliefFactor

    @start_of_linear_tip_relief_factor.setter
    def start_of_linear_tip_relief_factor(self, value: 'float'):
        self.wrapped.StartOfLinearTipReliefFactor = float(value) if value else 0.0

    @property
    def start_of_parabolic_tip_relief_factor(self) -> 'float':
        '''float: 'StartOfParabolicTipReliefFactor' is the original name of this property.'''

        return self.wrapped.StartOfParabolicTipReliefFactor

    @start_of_parabolic_tip_relief_factor.setter
    def start_of_parabolic_tip_relief_factor(self, value: 'float'):
        self.wrapped.StartOfParabolicTipReliefFactor = float(value) if value else 0.0

    @property
    def start_of_linear_root_relief_factor(self) -> 'float':
        '''float: 'StartOfLinearRootReliefFactor' is the original name of this property.'''

        return self.wrapped.StartOfLinearRootReliefFactor

    @start_of_linear_root_relief_factor.setter
    def start_of_linear_root_relief_factor(self, value: 'float'):
        self.wrapped.StartOfLinearRootReliefFactor = float(value) if value else 0.0

    @property
    def start_of_parabolic_root_relief_factor(self) -> 'float':
        '''float: 'StartOfParabolicRootReliefFactor' is the original name of this property.'''

        return self.wrapped.StartOfParabolicRootReliefFactor

    @start_of_parabolic_root_relief_factor.setter
    def start_of_parabolic_root_relief_factor(self, value: 'float'):
        self.wrapped.StartOfParabolicRootReliefFactor = float(value) if value else 0.0

    @property
    def use_user_specified_barrelling_peak_point(self) -> 'bool':
        '''bool: 'UseUserSpecifiedBarrellingPeakPoint' is the original name of this property.'''

        return self.wrapped.UseUserSpecifiedBarrellingPeakPoint

    @use_user_specified_barrelling_peak_point.setter
    def use_user_specified_barrelling_peak_point(self, value: 'bool'):
        self.wrapped.UseUserSpecifiedBarrellingPeakPoint = bool(value) if value else False

    @property
    def barrelling_peak_point_factor(self) -> 'float':
        '''float: 'BarrellingPeakPointFactor' is the original name of this property.'''

        return self.wrapped.BarrellingPeakPointFactor

    @barrelling_peak_point_factor.setter
    def barrelling_peak_point_factor(self, value: 'float'):
        self.wrapped.BarrellingPeakPointFactor = float(value) if value else 0.0

    @property
    def use_measured_data(self) -> 'bool':
        '''bool: 'UseMeasuredData' is the original name of this property.'''

        return self.wrapped.UseMeasuredData

    @use_measured_data.setter
    def use_measured_data(self, value: 'bool'):
        self.wrapped.UseMeasuredData = bool(value) if value else False

    @property
    def measured_data(self) -> '_1315.Vector2DListAccessor':
        '''Vector2DListAccessor: 'MeasuredData' is the original name of this property.'''

        return constructor.new(_1315.Vector2DListAccessor)(self.wrapped.MeasuredData) if self.wrapped.MeasuredData else None

    @measured_data.setter
    def measured_data(self, value: '_1315.Vector2DListAccessor'):
        value = value.wrapped if value else None
        self.wrapped.MeasuredData = value



'''_44.py

AbstractNodalMatrix
'''


from mastapy import _0
from mastapy._internal.python_net import python_net_import

_ABSTRACT_NODAL_MATRIX = python_net_import('SMT.MastaAPI.NodalAnalysis', 'AbstractNodalMatrix')


__docformat__ = 'restructuredtext en'
__all__ = ('AbstractNodalMatrix',)


class AbstractNodalMatrix(_0.APIBase):
    '''AbstractNodalMatrix

    This is a mastapy class.
    '''

    TYPE = _ABSTRACT_NODAL_MATRIX

    __hash__ = None

    def __init__(self, instance_to_wrap: 'AbstractNodalMatrix.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_2040.py

ZerolBevelGearMesh
'''


from mastapy.gears.gear_designs.zerol_bevel import _891
from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets.gears import _2012
from mastapy._internal.python_net import python_net_import

_ZEROL_BEVEL_GEAR_MESH = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets.Gears', 'ZerolBevelGearMesh')


__docformat__ = 'restructuredtext en'
__all__ = ('ZerolBevelGearMesh',)


class ZerolBevelGearMesh(_2012.BevelGearMesh):
    '''ZerolBevelGearMesh

    This is a mastapy class.
    '''

    TYPE = _ZEROL_BEVEL_GEAR_MESH

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ZerolBevelGearMesh.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def bevel_gear_mesh_design(self) -> '_891.ZerolBevelGearMeshDesign':
        '''ZerolBevelGearMeshDesign: 'BevelGearMeshDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_891.ZerolBevelGearMeshDesign)(self.wrapped.BevelGearMeshDesign) if self.wrapped.BevelGearMeshDesign else None

    @property
    def zerol_bevel_gear_mesh_design(self) -> '_891.ZerolBevelGearMeshDesign':
        '''ZerolBevelGearMeshDesign: 'ZerolBevelGearMeshDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_891.ZerolBevelGearMeshDesign)(self.wrapped.ZerolBevelGearMeshDesign) if self.wrapped.ZerolBevelGearMeshDesign else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2273 import GearMaterialExpertSystemMaterialDetails
    from ._2274 import GearMaterialExpertSystemMaterialOptions



'''_4289.py

BoltedJointModalAnalysisAtAStiffness
'''


from mastapy.system_model.part_model import _2152
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6512
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import _4369
from mastapy._internal.python_net import python_net_import

_BOLTED_JOINT_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness', 'BoltedJointModalAnalysisAtAStiffness')


__docformat__ = 'restructuredtext en'
__all__ = ('BoltedJointModalAnalysisAtAStiffness',)


class BoltedJointModalAnalysisAtAStiffness(_4369.SpecialisedAssemblyModalAnalysisAtAStiffness):
    '''BoltedJointModalAnalysisAtAStiffness

    This is a mastapy class.
    '''

    TYPE = _BOLTED_JOINT_MODAL_ANALYSIS_AT_A_STIFFNESS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BoltedJointModalAnalysisAtAStiffness.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2152.BoltedJoint':
        '''BoltedJoint: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2152.BoltedJoint)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6512.BoltedJointLoadCase':
        '''BoltedJointLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6512.BoltedJointLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None
